@@ -2,7 +2,7 @@
 
 package TPath::Grammar;
 {
-  $TPath::Grammar::VERSION = '0.001';
+  $TPath::Grammar::VERSION = '0.002';
 }
 
 use v5.10;
@@ -171,10 +171,68 @@ sub parse {
             merge_conditions($ref);
             fix_predicates($ref);
         }
-        return $ref;
+        return optimize($ref);
     }
     else {
-        confess "could not parse '$expr' as a TPath expression:\n" . join "\n", @!;
+        confess "could not parse '$expr' as a TPath expression:\n" . join "\n",
+          @!;
+    }
+}
+
+# remove no-op steps etc.
+sub optimize {
+    my $ref = shift;
+    clean_no_op($ref);
+    return $ref;
+}
+
+# remove . and /. steps
+sub clean_no_op {
+    my $ref = shift;
+    for ( ref $ref ) {
+        when ('HASH') {
+            my $paths = $ref->{path};
+            for my $path ( @{ $paths // [] } ) {
+                my @segments = @{ $path->{segment} };
+                my @cleaned;
+                for my $i ( 1 .. $#segments ) {
+                    my $step = $segments[$i];
+                    push @cleaned, $step
+                      unless ( $step->{step}{abbreviated} // '' ) eq '.';
+                }
+                if (@cleaned) {
+                    my $step = $segments[0];
+                    if ( ( $step->{step}{abbreviated} // '' ) eq '.' ) {
+                        my $sep  = $step->{separator};
+                        my $next = $cleaned[0];
+                        my $nsep = $next->{separator};
+                        if ($sep) {
+                            unshift @cleaned, $step
+                              unless $nsep eq '/' && $next->{step}{full}{axis};
+                        }
+                        else {
+                            if ( $nsep eq '/' ) {
+                                delete $next->{separator};
+                            }
+                            else {
+                                unshift @cleaned, $step;
+                            }
+                        }
+                    }
+                    else {
+                        unshift @cleaned, $step;
+                    }
+                }
+                else {
+                    @cleaned = @segments;
+                }
+                $path->{segment} = \@cleaned;
+            }
+            clean_no_op($_) for values %$ref;
+        }
+        when ('ARRAY') {
+            clean_no_op($_) for @$ref;
+        }
     }
 }
 
@@ -448,7 +506,7 @@ TPath::Grammar - parses TPath expressions into ASTs
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -458,7 +516,7 @@ version 0.001
 
 =head1 DESCRIPTION
 
-c<TPath::Grammar> exposes a single function: C<parse>. Parsing is a preliminary step to
+C<TPath::Grammar> exposes a single function: C<parse>. Parsing is a preliminary step to
 compiling the expression into an object that will select the tree nodes matching
 the expression.
 
